ps2000aBlockReady

Type Alias ps2000aBlockReady 

pub type ps2000aBlockReady = Option<unsafe extern "C" fn(handle: i16, status: PICO_STATUS, pParameter: *mut c_void)>;
This callback function is part of your application. You register it with the ps3000a driver using series RunBlock, and the driver calls it back when block-mode data is ready. You can then download the data using series GetValues. Device identifier returned by OpenUnit. Indicates whether an error occurred during collection of the data. A void pointer passed from series RunBlock. Your callback function can write to this location to send any data, such as a status flag, back to your application.

Aliased Type

pub enum ps2000aBlockReady {
    None,
    Some(unsafe extern "C" fn(i16, u32, *mut c_void)),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(i16, u32, *mut c_void))

Some value of type T.